@@ -89,10 +89,11 @@ class gPodderExtension(object):
         INTRO_DEFAULT = 15
         try:
             # intro in the data could be 15 or 15.33
-            intro = episode_data.split('introDuration%22%3A')[1] \
-                                .split('%2C')[0] or INTRO_DEFAULT
+            intro = episode_data
+            intro = episode_data.split('introDuration":')[1] \
+                                .split(',')[0] or INTRO_DEFAULT
             intro = int(float(intro)*1000)
-        except ValueError, e:
+        except (ValueError, IndexError), e:
             logger.info("Couldn't parse introDuration string: %s", intro)
             intro = INTRO_DEFAULT * 1000
         current_filename = episode.local_filename(create=False)
